==> ruby-google-apis-cloudbilling-v1_0.21.0.orig.tar.gz: google-apis-cloudbilling-v1-0.21.0/lib/google/apis/cloudbilling_v1.rb <==
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'google/apis/cloudbilling_v1/service.rb'
require 'google/apis/cloudbilling_v1/classes.rb'
require 'google/apis/cloudbilling_v1/representations.rb'
require 'google/apis/cloudbilling_v1/gem_version.rb'

module Google
  module Apis
    # Cloud Billing API
    #
    # Allows developers to manage billing for their Google Cloud Platform projects
    # programmatically.
    #
    # @see https://cloud.google.com/billing/
    module CloudbillingV1
      # Version of the Cloud Billing API this client connects to.
      # This is NOT the gem version.
      VERSION = 'V1'

      # View and manage your Google Cloud Platform billing accounts
      AUTH_CLOUD_BILLING = 'https://www.googleapis.com/auth/cloud-billing'

      # View your Google Cloud Platform billing accounts
      AUTH_CLOUD_BILLING_READONLY = 'https://www.googleapis.com/auth/cloud-billing.readonly'

      # See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
      AUTH_CLOUD_PLATFORM = 'https://www.googleapis.com/auth/cloud-platform'
    end
  end
end

==> ruby-google-apis-cloudbilling-v1_0.39.0.orig.tar.gz: google-apis-cloudbilling_v1-0.39.0/lib/google/apis/cloudbilling_v1.rb <==
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'google/apis/cloudbilling_v1/service.rb'
require 'google/apis/cloudbilling_v1/classes.rb'
require 'google/apis/cloudbilling_v1/representations.rb'
require 'google/apis/cloudbilling_v1/gem_version.rb'

module Google
  module Apis
    # Cloud Billing API
    #
    # Allows developers to manage billing for their Google Cloud Platform projects
    # programmatically.
    #
    # @see https://cloud.google.com/billing/docs/apis
    module CloudbillingV1
      # Version of the Cloud Billing API this client connects to.
      # This is NOT the gem version.
      VERSION = 'V1'

      # View and manage your Google Cloud Platform billing accounts
      AUTH_CLOUD_BILLING = 'https://www.googleapis.com/auth/cloud-billing'

      # View your Google Cloud Platform billing accounts
      AUTH_CLOUD_BILLING_READONLY = 'https://www.googleapis.com/auth/cloud-billing.readonly'

      # See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
      AUTH_CLOUD_PLATFORM = 'https://www.googleapis.com/auth/cloud-platform'
    end
  end
end
